/* 	Barbara Sianesi
	POLICY EVALUATION METHODS Course
	
	STATA SESSION 4a -- REGRESSION DISCONTINUITY DESIGN: SHARP	 
******************************************************************/

//************************************************************************
// 	IV.1 Sharp design     							
//************************************************************************


use nsw_psid_rdd, clear

// a) Eligibles, characteristics and outcomes within discountinuity samples
//***************************************************************************

// Eligibility indicator
gen eligible = re75<=1000
lab var eligible "Eligible, re75<=1000"

// Discontinuity samples indicators
gen ds5 = 1 if re75>=(1000-500) & re75<=(1000+500)
gen ds2 = 1 if re75>=(1000-200) & re75<=(1000+200)
gen ds1 = 1 if re75>=(1000-100) & re75<=(1000+100)


ta eligible 
pstest age black, raw tr(eligible)
regress re78 eligible, robust 

ta eligible if ds5==1
pstest age black if ds5==1, raw tr(eligible)
regress re78 eligible if ds5==1, robust

ta eligible if ds2==1
pstest age black if ds2==1, raw tr(eligible)
regress re78 eligible if ds2==1, robust

ta eligible if ds1==1
pstest age black if ds1==1, raw tr(eligible)
regress re78 eligible if ds1==1, robust


// b) RDD plots
//************************************************************************

*net install rdrobust, from(http://www-personal.umich.edu/~cattaneo/software/rdrobust/stata) replace

// P(D=1 | Z)
rdplot eligible re75 if re75<2000, c(1000)

// E(Y | Z)
rdplot re78 re75, c(1000) 
rdplot re78 re75 if re75<2000, c(1000)

// Trying out different bin choices...
rdplot re78 re75 if re75<2000, c(1000) numbinl(20) numbinr(20)   graph_options(ylab(500(500)2500))
rdplot re78 re75 if re75<2000, c(1000) numbinl(150) numbinr(150) graph_options(ylab(500(500)2500))
rdplot re78 re75 if re75<2000, c(1000) binselect(es) graph_options(ylab(500(500)2500)) 
rdplot re78 re75 if re75<2000, c(1000) binselect(qsmv) graph_options(ylab(500(500)2500)) 

// Trying out different model choices...
rdplot re78 re75 if re75<2000, c(1000) graph_options(ylab(500(500)2500))
rdplot re78 re75 if re75<2000, c(1000) p(1) graph_options(ylab(500(500)2500))
rdplot re78 re75 if re75<2000, c(1000) p(2) graph_options(ylab(500(500)2500))
rdplot re78 re75 if re75<2000, c(1000) p(3) graph_options(ylab(500(500)2500)) 


// c) SRD estimates - parametric, modelling E(Y0|Z)
//************************************************************************

forvalues i=2/4 {
	cap drop re75_`i'
	gen re75_`i' = re75^`i'
}

// Linear model
regress re78 eligible re75, robust

// Quadratic model
regress re78 eligible re75 re75_2, robust

// Cubic model
regress re78 eligible re75 re75_2 re75_3, robust

// 4th order polynomial model
regress re78 eligible re75 re75_2 re75_3 re75_4, robust

// Controlling for X
regress re78 eligible re75 re75_2 re75_3 re75_4 age black, robust

	
// In discountinuity samples
regress re78 eligible re75 re75_2 if ds2==1, robust
regress re78 eligible re75 if ds2==1, robust

regress re78 eligible re75 re75_2 if ds1==1, robust
regress re78 eligible re75 if ds1==1, robust
regress re78 eligible if ds1==1, robust


// d) SRD estimates - parametric, modelling E(Y0|Z) & E(Y1|Z)
//************************************************************************

cap drop Zc
cap drop Zc_2
cap drop DZc
cap drop DZc_2

gen Zc    = re75 - 1000
gen Zc_2  = Zc^2	
gen DZc   = eligible*Zc
gen DZc_2 = eligible*Zc_2

regress re78 eligible Zc* DZc*, robust


// e) SRD estimates - non-parametric LLR
//************************************************************************

// fully data-driven RD treatment-effects estimation and inference
rdrobust re78 re75, c(1000) 
* take MINUS the effect as discountinuity the other way round

rdrobust re78 re75, c(1000) bwselect(msetwo)
rdrobust re78 re75, c(1000) bwselect(certwo)


// d) Specification checks
//************************************************************************

// Balancing of covariates **************************************
rdplot age re75 if re75<2000, c(1000)
rdrobust age re75, c(1000) 

rdplot black re75 if re75<2000, c(1000)
rdrobust black re75, c(1000) 

// Placebo discontinuities *************************************** 
su re75 if re75<=1000, d
rdplot re78 re75 if re75<2000, c(710)
rdrobust re78 re75 if re75<2000, c(710)

su re75 if re75>1000 & re75<=2000, d
rdplot re78 re75 if re75<2000, c(1600) 
rdrobust re78 re75 if re75<2000, c(1600)

// Testing for bunching of Z at z0 ************************************* 
cap drop X Y r0 fhat se_fhat
DCdensity re75, breakpoint(1000) generate(X Y r0 fhat se_fhat)


