/* 	Barbara Sianesi
	POLICY EVALUATION METHODS Course
	
	STATA SESSION 4b -- REGRESSION DISCONTINUITY DESIGN: FUZZY	 
******************************************************************/
	
//************************************************************************
// 	IV.2 Fuzzy design     							
//************************************************************************

use nsw_psid_rdd, clear

// a) P(D=1 | Z)
rdplot treated re75 if re75<2000, c(1000)


// b) Parametric - IV via 2SLS
//************************************************************************

forvalues i=2/4 {
	cap drop re75_`i'
	gen re75_`i' = re75^`i'
}

// Instrument is jump (which is the same as eligible)
gen jump = re75<=1000

// First stage
regress treated jump re75*

ivregress 2sls re78 re75 (treated = jump), first robust
ivregress 2sls re78 re75 re75_2 (treated = jump), first robust
ivregress 2sls re78 re75 re75_2 re75_3 (treated = jump), first robust
ivregress 2sls re78 re75* (treated = jump), first robust

// Covariates
ivregress 2sls re78 re75* age black (treated = jump), first robust


// c) 2SLS within discountinuity samples
//************************************************************************

gen ds5 = 1 if re75>=(1000-500) & re75<=(1000+500)
gen ds2 = 1 if re75>=(1000-200) & re75<=(1000+200)
gen ds1 = 1 if re75>=(1000-100) & re75<=(1000+100)

// Within discontinuity sample -
ivregress 2sls re78 re75* (treated = jump) if ds5==1, first
ivregress 2sls re78 re75 re75_2 (treated = jump) if ds5==1, first
ivregress 2sls re78 re75 (treated = jump) if ds5==1, first

// Nearest discountinuity sample
ivregress 2sls re78 re75 (treated = jump) if ds2==1, first
ivregress 2sls re78 (treated = jump) if ds1==1, first


// d) Non-parametric Wald estimator (local LATE)
//************************************************************************
rdrobust re78 re75, c(1000) fuzzy(treated)





