/* 	Barbara Sianesi
	POLICY EVALUATION METHODS Course
	
	STATA SESSION -- IMPLEMENTING MATCHING METHODs  */
//*****************************************************

	
use nsw_psid, clear

	
// Propensity score   						
//**********************************************************
	
dprobit treated age black hispanic married educ nodegree re75
predict score
	

// Common support    						 
//**********************************************************
summarize score if treated== 1, detail	
summarize score if treated== 0, detail
		
psgraph, treated(treated) pscore(score) bin(50)

pstest score, raw t(treated) dens
pstest score, raw t(treated) box outlier


// Nearest neighbour with replacement without caliper         
//**********************************************************
	
psmatch2 treated, pscore(score) outcome(re78)
desc _*
tab _weight if treated==0

summarize re78 if treated==1 [fw=_weight]
scalar y1 = r(mean)
summarize re78 if treated==0 [fw=_weight]
scalar y0 = r(mean)
display y1-y0
	
regress re78 treated [fw=_weight]


// Caliper matching 							
//**********************************************************	
summarize _pdif, detail
psmatch2 treated, pscore(score) outcome(re78) caliper(0.01)	
summarize _support if treated==1
display  1-r(mean)
psgraph
	

// Matching quality 						
//**********************************************************
psmatch2 treated, pscore(score) outcome(re78) caliper(0.01) 	
pstest score, both dens 
pstest score, both box
		
pstest age black hispanic married educ nodegree re75, both graph
pstest age black hispanic married educ nodegree re75, both scatter

pstest re75 if re75<40000, both dens
pstest re75, both box
pstest re75, both box outlier
pstest age,  both box
	
// Nearest neighbour WITHOUT replacement and WITHOUT caliper 
//***************************************************************
psmatch2 treated, pscore(score) outcome(re78) noreplacement
summarize _pdif, detail
pstest age black hispanic married educ nodegree re75, both scatter 
pstest re75, box  
	
	
// Nearest neighbour WITHOUT replacement with caliper     
//**********************************************************
psmatch2 treated, pscore(score) outcome(re78) caliper(0.01) noreplacement

summarize _support if treated==1
display  1-r(mean)
psgraph

pstest age black hispanic married educ nodegree re75, both scatter 	
pstest re75, box  
	
pstest age black hispanic married educ nodegree re75 if treated==1, raw tr(_support)  
pstest re78 if treated==1, raw tr(_support)  
	

// >1-to-1  matching   					 
//**********************************************************	
psmatch2 treated, pscore(score) outcome(re78) neigh(10)
psmatch2 treated, pscore(score) outcome(re78) neigh(20)
	
psmatch2 treated, pscore(score) outcome(re78) neigh(10) cal(0.01)
tab _nn if treated==1
	
psmatch2 treated, pscore(score) outcome(re78) neigh(20) cal(0.01)
tab _nn if treated==1
	
// Kernel matching        						
//**********************************************************	
psmatch2 treated, pscore(score) outcome(re78) kernel
psmatch2 treated, pscore(score) outcome(re78) kernel k(normal)

psmatch2 treated, pscore(score) outcome(re78) kernel bw(0.01)
psmatch2 treated, pscore(score) outcome(re78) kernel k(normal) bw(0.01)

psmatch2 treated, pscore(score) outcome(re78) kernel k(normal) bw(2)


// Mahalanobis-metric matching 					
//**********************************************************
psmatch2 treated, mahal(age black hispanic married educ nodegree re75) outcome(re78) 
pstest age black hispanic married educ nodegree re75, both scatter

psmatch2 treated, mahal(score age black hispanic married educ nodegree re75) outcome(re78) 
pstest age black hispanic married educ nodegree re75, both scatter


// Compare Mahal-metric matching to randomisation for balancing
//***************************************************************
use nsw.dta, clear		
pstest age black hispanic married educ nodegree re75, raw tr(treated) scatter  
use nsw_psid, clear
	

// Common Support at the boundary: kernel matching
//**********************************************************
psmatch2 treated age black hispanic married educ nodegree re75, quietly outcome(re78) kernel common 
psmatch2 treated age black hispanic married educ nodegree re75, quietly outcome(re78) kernel k(normal) common 


// Inference
//**********************************************************

// Standard errors for nearest neighbours that appropriately take into account estimation of the pscore:
// In Stata 13:
teffects psmatch (re78) (treat age black hispanic married educ nodegree re75, probit), atet
	
// ATT equivalent to:
psmatch2 treated age black hispanic married educ nodegree re75, outc(re78) qui ties

// Abadie-Imbens std errors allowing for heteroskedasticity in Mahal-metric matching	
psmatch2 treated, mahal(age black hispanic married educ nodegree re75) outcome(re78) ai(5) 

// Bootstrapping (especially for kernel matching) 									
bs "psmatch2 treated age black hispanic married educ nodegree re75, outc(re78) kernel" /*
*/                                                "r(att)", reps(50) dots

/* Alternative: new but cumbersome syntax: */
// bootstrap r(att), reps(50): psmatch2 treated age black hispanic married educ nodegree re75, outc(re78) kernel
// estat bootstrap

	
